MainAppState class

Inheritance
Mixed-in types

Constructors

MainAppState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentState ↔ ApplicationState
getter/setter pairinherited
frame ↔ BrilliantDevice?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → MainApp
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
cancel() → Future<void>
cancel the current photo
override
connectToScannedFrame(BrilliantScannedDevice device) → Future<void>
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant MainApp oldWidget) → void
Called whenever the widget configuration changes.
inherited
disconnectFrame() → Future<void>
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getBatteryWidget() → Widget
inherited
getFloatingActionButtonWidget(Icon ready, Icon running) → FloatingActionButton?
inherited
getFooterButtonsWidget() → List<Widget>
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
reconnectFrame() → Future<void>
inherited
run() → Future<void>
the SimpleFrameApp subclass implements application-specific code
override
scanForFrame() → Future<void>
inherited
scanOrReconnectFrame() → Future<void>
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showLoadingScreen() → Future<void>
inherited
startApplication() → Future<void>
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
stopApplication() → Future<void>
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
tryScanAndConnectAndStart({required bool andRun}) → Future<void>
Suitable for inclusion in initState or other startup code, this function will attempt connection, start app (loading Lua, sprites) and optionally call run() (unawaited) to save a few connect/start/(run) steps
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited