MainAppState class
Constructors
Properties
- analogGainLimit ↔ int
-
getter/setter pairinherited
- autoExpGainTimes ↔ int
-
getter/setter pairinherited
- autoExpInterval ↔ int
-
getter/setter pairinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- currentState ↔ ApplicationState
-
getter/setter pairinherited
- exposure ↔ double
-
getter/setter pairinherited
- exposureSpeed ↔ double
-
getter/setter pairinherited
- frame ↔ BrilliantDevice?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- manualAnalogGain ↔ int
-
getter/setter pairinherited
- manualBlueGain ↔ int
-
getter/setter pairinherited
- manualGreenGain ↔ int
-
getter/setter pairinherited
- manualRedGain ↔ int
-
getter/setter pairinherited
- manualShutter ↔ int
-
getter/setter pairinherited
- meteringIndex ↔ int
-
getter/setter pairinherited
-
meteringValues
→ List<
String> -
finalinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- qualityIndex ↔ int
-
getter/setter pairinherited
-
qualityValues
→ List<
double> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shutterLimit ↔ int
-
getter/setter pairinherited
- whiteBalanceSpeed ↔ double
-
getter/setter pairinherited
- widget → MainApp
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
cancel(
) → Future< void> -
cancel tap-listening state and clear the display
inherited
-
capture(
) → Future< (Uint8List, ImageMetadata)> -
request a photo from Frame
inherited
-
connectToScannedFrame(
BrilliantScannedDevice device) → Future< void> -
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant MainApp oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
disconnectFrame(
) → Future< void> -
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
getBatteryWidget(
) → Widget -
inherited
-
getCameraDrawer(
) → Drawer -
inherited
-
getFloatingActionButtonWidget(
Icon ready, Icon running) → FloatingActionButton? -
inherited
-
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printInstructions(
) → Future< void> -
abstract method that is called at the end of run() to give the implementing class
a chance to print some instructions (or perform some other final setup)
after the tap handler is hooked up
override
-
process(
(Uint8List, ImageMetadata) photo) → FutureOr< void> - The vision pipeline to run when a photo is captured
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
reconnectFrame(
) → Future< void> -
inherited
-
run(
) → Future< void> -
Implements simple_frame_app run() by listening for taps
and handing off to a tapHandler() function
in the class that mixes in frame_vision_app.
That function would be expected to call capture() and
then perform processing on the image
inherited
-
scanForFrame(
) → Future< void> -
inherited
-
scanOrReconnectFrame(
) → Future< void> -
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
showLoadingScreen(
) → Future< void> -
inherited
-
startApplication(
) → Future< void> -
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
-
stopApplication(
) → Future< void> -
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
-
tapHandler(
int taps) → Future< void> -
abstract method that must be implemented by the class mixing in frame_vision_app
to capture a photo and perform some action on a 1-, 2-, 3-, n-tap etc.
override
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
tryScanAndConnectAndStart(
{required bool andRun}) → Future< void> -
Suitable for inclusion in initState or other startup code,
this function will attempt connection, start app (loading Lua, sprites)
and optionally call run() (unawaited)
to save a few connect/start/(run) steps
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited